# Generated by ariadne-codegen
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import SlimSubscriptionFragment


class DelegateSubscriptionToCustomer(BaseModel):
    delegate_subscription_to_customer: "DelegateSubscriptionToCustomerDelegateSubscriptionToCustomer" = Field(
        alias="delegateSubscriptionToCustomer"
    )


class DelegateSubscriptionToCustomerDelegateSubscriptionToCustomer(
    SlimSubscriptionFragment
):
    pass


DelegateSubscriptionToCustomer.model_rebuild()
